@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2009 Jeffrey Stedfast
+ *  Copyright (C) 2000-2008 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -118,24 +118,25 @@ filter_copy (GMimeFilter *filter)
 }
 
 static void
-filter_filter (GMimeFilter *filter, char *in, size_t len, size_t prespace,
-	       char **out, size_t *outlen, size_t *outprespace)
+filter_filter (GMimeFilter *filter, char *inbuf, size_t inlen, size_t prespace,
+	       char **outbuf, size_t *outlen, size_t *outprespace)
 {
 	GMimeFilterBest *best = (GMimeFilterBest *) filter;
 	register unsigned char *inptr, *inend;
+	register unsigned char c;
 	size_t left;
 	
 	if (best->flags & GMIME_FILTER_BEST_CHARSET)
-		g_mime_charset_step (&best->charset, in, len);
+		g_mime_charset_step (&best->charset, inbuf, inlen);
 	
 	if (best->flags & GMIME_FILTER_BEST_ENCODING) {
-		best->total += len;
+		best->total += inlen;
 		
-		inptr = (unsigned char *) in;
-		inend = inptr + len;
+		inptr = (unsigned char *) inbuf;
+		inend = inptr + inlen;
 		
 		while (inptr < inend) {
-			register unsigned char c = '\0';
+			c = 0;
 			
 			if (best->midline) {
 				while (inptr < inend && (c = *inptr++) != '\n') {
@@ -151,9 +152,9 @@ filter_filter (GMimeFilter *filter, char *in, size_t len, size_t prespace,
 				}
 				
 				if (c == '\n') {
+					best->maxline = MAX (best->maxline, best->linelen);
 					best->startline = TRUE;
 					best->midline = FALSE;
-					best->maxline = MAX (best->maxline, best->linelen);
 				}
 			}
 			
@@ -177,7 +178,6 @@ filter_filter (GMimeFilter *filter, char *in, size_t len, size_t prespace,
 				} else {
 					if (!strncmp ((char *) inptr, "From ", 5)) {
 						best->hadfrom = TRUE;
-						
 						inptr += 5;
 					}
 				}
@@ -188,9 +188,9 @@ filter_filter (GMimeFilter *filter, char *in, size_t len, size_t prespace,
 		}
 	}
 	
-	*out = in;
-	*outlen = len;
 	*outprespace = prespace;
+	*outlen = inlen;
+	*outbuf = inbuf;
 }
 
 static void 
@@ -237,10 +237,10 @@ filter_reset (GMimeFilter *filter)
  * Note: In order for the g_mime_filter_best_charset() function to
  * work, the stream being filtered MUST already be encoded in UTF-8.
  *
- * Returns a new best filter with flags @flags.
+ * Returns: a new best filter with flags @flags.
  **/
 GMimeFilter *
-g_mime_filter_best_new (unsigned int flags)
+g_mime_filter_best_new (GMimeFilterBestFlags flags)
 {
 	GMimeFilterBest *new;
 	
@@ -259,7 +259,7 @@ g_mime_filter_best_new (unsigned int flags)
  * Calculates the best charset for encoding the stream filtered
  * through the @best filter.
  *
- * Returns a pointer to a string containing the name of the charset
+ * Returns: a pointer to a string containing the name of the charset
  * best suited for the text filtered through @best.
  **/
 const char *
@@ -286,46 +286,46 @@ g_mime_filter_best_charset (GMimeFilterBest *best)
  * Calculates the best Content-Transfer-Encoding for the stream
  * filtered through @best that fits within the @required encoding.
  *
- * Returns the best encoding for the stream filtered by @best.
+ * Returns: the best encoding for the stream filtered by @best.
  **/
-GMimePartEncodingType
+GMimeContentEncoding
 g_mime_filter_best_encoding (GMimeFilterBest *best, GMimeBestEncoding required)
 {
-	GMimePartEncodingType encoding = GMIME_PART_ENCODING_DEFAULT;
+	GMimeContentEncoding encoding = GMIME_CONTENT_ENCODING_DEFAULT;
 	
-	g_return_val_if_fail (GMIME_IS_FILTER_BEST (best), GMIME_PART_ENCODING_DEFAULT);
+	g_return_val_if_fail (GMIME_IS_FILTER_BEST (best), GMIME_CONTENT_ENCODING_DEFAULT);
 	
 	if (!(best->flags & GMIME_FILTER_BEST_ENCODING))
-		return GMIME_PART_ENCODING_DEFAULT;
+		return GMIME_CONTENT_ENCODING_DEFAULT;
 	
 	switch (required) {
 	case GMIME_BEST_ENCODING_7BIT:
 		if (best->count0 > 0) {
-			encoding = GMIME_PART_ENCODING_BASE64;
+			encoding = GMIME_CONTENT_ENCODING_BASE64;
 		} else if (best->count8 > 0) {
 			if (best->count8 >= (best->total * 17 / 100))
-				encoding = GMIME_PART_ENCODING_BASE64;
+				encoding = GMIME_CONTENT_ENCODING_BASE64;
 			else
-				encoding = GMIME_PART_ENCODING_QUOTEDPRINTABLE;
+				encoding = GMIME_CONTENT_ENCODING_QUOTEDPRINTABLE;
 		} else if (best->maxline > 998) {
-			encoding = GMIME_PART_ENCODING_QUOTEDPRINTABLE;
+			encoding = GMIME_CONTENT_ENCODING_QUOTEDPRINTABLE;
 		}
 		break;
 	case GMIME_BEST_ENCODING_8BIT:
 		if (best->count0 > 0) {
-			encoding = GMIME_PART_ENCODING_BASE64;
+			encoding = GMIME_CONTENT_ENCODING_BASE64;
 		} else if (best->maxline > 998) {
-			encoding = GMIME_PART_ENCODING_QUOTEDPRINTABLE;
+			encoding = GMIME_CONTENT_ENCODING_QUOTEDPRINTABLE;
 		}
 		break;
 	case GMIME_BEST_ENCODING_BINARY:
 		if (best->count0 + best->count8 > 0)
-			encoding = GMIME_PART_ENCODING_BINARY;
+			encoding = GMIME_CONTENT_ENCODING_BINARY;
 		break;
 	}
 	
-	if (encoding == GMIME_PART_ENCODING_DEFAULT && best->hadfrom)
-		encoding = GMIME_PART_ENCODING_QUOTEDPRINTABLE;
+	if (encoding == GMIME_CONTENT_ENCODING_DEFAULT && best->hadfrom)
+		encoding = GMIME_CONTENT_ENCODING_QUOTEDPRINTABLE;
 	
 	return encoding;
 }
