@@ -1,23 +1,21 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/*
- *  Authors: Jeffrey Stedfast <fejj@ximian.com>
+/*  GMime
+ *  Copyright (C) 2000-2008 Jeffrey Stedfast
  *
- *  Copyright 2002-2004 Ximian, Inc. (www.ximian.com)
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Lesser General Public License
+ *  as published by the Free Software Foundation; either version 2.1
+ *  of the License, or (at your option) any later version.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
+ *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Lesser General Public License for more details.
  *
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this library; if not, write to the Free
+ *  Software Foundation, 51 Franklin Street, Fifth Floor, Boston, MA
+ *  02110-1301, USA.
  */
 
 
@@ -28,10 +26,7 @@
 
 #include <gmime/gmime-object.h>
 
-#ifdef __cplusplus
-extern "C" {
-#pragma }
-#endif /* __cplusplus */
+G_BEGIN_DECLS
 
 #define GMIME_TYPE_MULTIPART            (g_mime_multipart_get_type ())
 #define GMIME_MULTIPART(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GMIME_TYPE_MULTIPART, GMimeMultipart))
@@ -43,15 +38,23 @@ extern "C" {
 typedef struct _GMimeMultipart GMimeMultipart;
 typedef struct _GMimeMultipartClass GMimeMultipartClass;
 
+/**
+ * GMimeMultipart:
+ * @parent_object: parent #GMimeObject
+ * @children: array of MIME sub-parts
+ * @boundary: MIME boundary
+ * @preface: multipart preface
+ * @postface: multipart postface
+ *
+ * A base MIME multipart object.
+ **/
 struct _GMimeMultipart {
 	GMimeObject parent_object;
 	
+	GPtrArray *children;
 	char *boundary;
-	
 	char *preface;
 	char *postface;
-	
-	GList *subparts;
 };
 
 struct _GMimeMultipartClass {
@@ -59,7 +62,7 @@ struct _GMimeMultipartClass {
 	
 	void (* add_part) (GMimeMultipart *multipart, GMimeObject *part);
 	void (* add_part_at) (GMimeMultipart *multipart, GMimeObject *part, int index);
-	void (* remove_part) (GMimeMultipart *multipart, GMimeObject *part);
+	gboolean (* remove_part) (GMimeMultipart *multipart, GMimeObject *part);
 	
 	GMimeObject * (* remove_part_at) (GMimeMultipart *multipart, int index);
 	GMimeObject * (* get_part) (GMimeMultipart *multipart, int index);
@@ -85,7 +88,7 @@ const char *g_mime_multipart_get_postface (GMimeMultipart *multipart);
 
 void g_mime_multipart_add_part (GMimeMultipart *multipart, GMimeObject *part);
 void g_mime_multipart_add_part_at (GMimeMultipart *multipart, GMimeObject *part, int index);
-void g_mime_multipart_remove_part (GMimeMultipart *multipart, GMimeObject *part);
+gboolean g_mime_multipart_remove_part (GMimeMultipart *multipart, GMimeObject *part);
 
 GMimeObject *g_mime_multipart_remove_part_at (GMimeMultipart *multipart, int index);
 GMimeObject *g_mime_multipart_get_part (GMimeMultipart *multipart, int index);
@@ -100,8 +103,6 @@ void g_mime_multipart_foreach (GMimeMultipart *multipart, GMimePartFunc callback
 GMimeObject *g_mime_multipart_get_subpart_from_content_id (GMimeMultipart *multipart,
 							   const char *content_id);
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 #endif /* __GMIME_MULTIPART_H__ */
